@@ -1,37 +1,22 @@
-# import epyqlib.delegates
-# import epyqlib.txrx
-import io
-import os
-from PyQt5 import QtWidgets, uic
-# from PyQt5.QtGui import QFontMetrics
-from PyQt5.QtCore import QFile, QFileInfo, QTextStream, Qt
-from PyQt5.QtWidgets import QHeaderView
+from PyQt5 import QtWidgets
 
-# See file COPYING in this source tree
+import epyqlib.variableselectionview_ui
 import epyqlib.utils.qt
 
+
+# See file COPYING in this source tree
 __copyright__ = 'Copyright 2016, EPC Power Corp.'
 __license__ = 'GPLv2+'
 
 
 class VariableSelectionView(QtWidgets.QWidget):
     def __init__(self, parent=None, in_designer=False):
-        QtWidgets.QWidget.__init__(self, parent=parent)
+        super().__init__(parent=parent)
 
         self.in_designer = in_designer
 
-        ui = 'variableselectionview.ui'
-        # TODO: CAMPid 9549757292917394095482739548437597676742
-        if not QFileInfo(ui).isAbsolute():
-            ui_file = os.path.join(
-                QFileInfo.absolutePath(QFileInfo(__file__)), ui)
-        else:
-            ui_file = ui
-        ui_file = QFile(ui_file)
-        ui_file.open(QFile.ReadOnly | QFile.Text)
-        ts = QTextStream(ui_file)
-        sio = io.StringIO(ts.readAll())
-        self.ui = uic.loadUi(sio, self)
+        self.ui = epyqlib.variableselectionview_ui.Ui_Form()
+        self.ui.setupUi(self)
 
         self.ui.searchbox.connect_to_view(
             view=self.ui.tree_view,
@@ -54,4 +39,4 @@ class VariableSelectionView(QtWidgets.QWidget):
 
     @property
     def model(self):
-        return self.tree_view.model()
+        return self.ui.tree_view.model()
